==> node-sdk-0.1.7.tgz: package/esm/internal/audience.js <==
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { ResponseCode, } from "@streamdal/snitch-protos/protos/sp_common";
import { audienceKey, internal } from "./register.js";
export const addAudiences = (configs) => __awaiter(void 0, void 0, void 0, function* () {
    if (!configs.audiences || configs.audiences.length === 0) {
        return;
    }
    for (const audience of configs.audiences) {
        yield addAudience({ configs, audience });
    }
});
export const addAudience = ({ configs, audience }) => __awaiter(void 0, void 0, void 0, function* () {
    try {
        if (internal.audiences.has(audienceKey(audience))) {
            return;
        }
        const { response } = yield configs.grpcClient.newAudience({
            sessionId: configs.sessionId,
            audience,
        }, { meta: { "auth-token": configs.streamdalToken } });
        if (response.code === ResponseCode.OK) {
            internal.audiences.set(audienceKey(audience), new Map());
        }
        else {
            console.error("error adding audience", response.message);
        }
    }
    catch (error) {
        console.error("error adding audience", error);
    }
});

==> node-sdk-0.1.14.tgz: package/esm/internal/audience.js <==
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { ResponseCode } from "@streamdal/protos/protos/sp_common";
import { audienceKey, internal } from "./register.js";
export const addAudiences = (configs) => __awaiter(void 0, void 0, void 0, function* () {
    if (!configs.audiences || configs.audiences.length === 0) {
        return;
    }
    for (const audience of configs.audiences) {
        yield addAudience({ configs, audience });
    }
});
export const addAudience = ({ configs, audience }) => __awaiter(void 0, void 0, void 0, function* () {
    try {
        if (internal.audiences.has(audienceKey(audience))) {
            return;
        }
        const { response } = yield configs.grpcClient.newAudience({
            sessionId: configs.sessionId,
            audience,
        }, { meta: { "auth-token": configs.streamdalToken } });
        if (response.code === ResponseCode.OK) {
            internal.audiences.set(audienceKey(audience), {
                audience,
                tails: new Map(),
            });
        }
        else {
            console.error("error adding audience", response.message);
        }
    }
    catch (error) {
        console.error("error adding audience", error);
    }
});
